==> graph-frontend-0.3.12.tgz: package/src/utils/utils.js <==
var {
  THREE,
  Edge,
  Node,
  OrbitControls,
  d3,
  ee,
  DEF_NODE_COLOR,
  DEF_NODE_HIGHLIGHT,
  DEF_ADJACENT_HIGHLIGHT,
  DEF_NODE_HTEXTURE,
  DEF_NODE_TEXTURE,
  DEF_NODE_NO_HTEX,
  DEF_NODE_NO_TEX,
  DEF_NODE_NO_HCOLOR,
  DEF_NODE_NO_COLOR,
  DEF_NODE_NO_HIGHLIGHT,
  DEF_NODE_SHAPE,
  DEF_NODE_HSHAPE,
  DEF_NODE_SIZE,
  DEF_HIGHLIGHT_SIZE,
  DEF_LAYOUT,
  DEF_LINES,
  DEF_MAP,
  DEF_TEXT_SCALE,
  DEF_TEXT_SIZE,
  DEF_TEXT_X_OFFSET,
  DEF_TEXT_Y_OFFSET,
  DEF_TEXT_BACK_COLOR,
  DEF_TEXT_OPACITY,
  TEXT_WIREFRAME
} = require('../imports').default;

var relMouseCoords = function (event, currentElement) {
  var totalOffsetX = 0;
  var totalOffsetY = 0;
  var canvasX = 0;
  var canvasY = 0;

  do {
    totalOffsetX += currentElement.offsetLeft - currentElement.scrollLeft;
    totalOffsetY += currentElement.offsetTop - currentElement.scrollTop;
  }
  while(currentElement = currentElement.offsetParent)

  canvasX = event.pageX - totalOffsetX;
  canvasY = event.pageY - totalOffsetY;

  return {x:canvasX, y:canvasY}
}

/**
 *  Creates a graph
 */
var randomGraph = function (Frame) {
  var nodeToAdd = null;
  for (var i = 0; i < 1000; i++) {
    var oldNode = nodeToAdd;
    nodeToAdd = new Node(i, DEF_NODE_SIZE);
    nodeToAdd.renderData = {
      'label': "This is node " + i, 'shape': 'square', 'size': DEF_NODE_SIZE,
      'linecolor': new THREE.Color(0.8, 0.8, 0.8)
    };
    nodeToAdd.x = 0;
    nodeToAdd.y = 0;
    nodeToAdd.vx = 0;
    nodeToAdd.vy = 0;
    Frame.addNode(nodeToAdd);
    if (i > 0) {
      Frame.addEdge(oldNode, nodeToAdd);
    }
  }
};

/**
 * Add metadata to node
 */
var prepNode = function (node) {
  let nodeToAdd = node;
  if (!node.data) {
    node.data = {};
  }
  nodeToAdd.renderData = {
    label: node.data.label || "No Label",
    color: node.data.color || DEF_NODE_COLOR,
    hcolor: node.data.hcolor || DEF_NODE_HIGHLIGHT,
    shape: node.data.shape || DEF_NODE_SHAPE,
    linecolor: new THREE.Color(0.5, 0.5, 0.5),
    numYeast: Math.ceil(Math.random() * 8),
    size: node.data.size,
    tsize: node.data.tsize || DEF_TEXT_SIZE,
    x: 0,
    y: 0,
    vx: 0,
    vy: 0
  };
  return nodeToAdd;
}

  /**
  * Creates a generic rectangle shape to use for selection and boundaries
  */
var make1x1Rect = function() {
  var rectShape = new THREE.Shape();
  rectShape.moveTo(0, 0);
  rectShape.lineTo(0, 1);
  rectShape.lineTo(1, 1);
  rectShape.lineTo(1, 0);
  rectShape.lineTo(0, 0);
  rectShape.lineTo(0, 1);
  return new THREE.ShapeGeometry(rectShape);
};
/**
* Creates a centered 2x2 Rectangle
*/
var make2x2Rect = function() {
  var rectShape = new THREE.Shape();
  rectShape.moveTo(-1, -1);
  rectShape.lineTo(-1, 1);
  rectShape.lineTo(1, 1);
  rectShape.lineTo(1, -1);
  rectShape.lineTo(-1, -1);
  return new THREE.ShapeGeometry(rectShape);
};
  

exports.relMouseCoords = relMouseCoords;
exports.randomGraph = randomGraph;
exports.prepNode = prepNode;
exports.make1x1Rect = make1x1Rect;
exports.make2x2Rect = make2x2Rect;

==> graph-frontend-0.3.15.tgz: package/src/utils/utils.js <==
var def = require('../imports').default;
var THREE = def.THREE;
var Edge = def.Edge;
var Node = def.Node;
var OrbitControls = def.OrbitControls;
var d3 = def.d3;
var ee = def.ee;

/**
 * Calculates coordinates of mouse on canvas adjusted for padding
 * @param {*} event 
 * @param {*} currentElement 
 */
var relMouseCoords = function (event, currentElement) {
  var totalOffsetX = 0;
  var totalOffsetY = 0;
  var canvasX = 0;
  var canvasY = 0;

  do {
    totalOffsetX += currentElement.offsetLeft - currentElement.scrollLeft;
    totalOffsetY += currentElement.offsetTop - currentElement.scrollTop;
  }
  while(currentElement = currentElement.offsetParent)

  canvasX = event.pageX - totalOffsetX;
  canvasY = event.pageY - totalOffsetY;

  return {x:canvasX, y:canvasY}
}

/**
 * Add metadata to node
 * @param {*} node 
 */
var prepNode = function (node) {
  let nodeToAdd = node;
  if (!node.data) {
    node.data = {};
  }
  nodeToAdd.renderData = {
    label: node.data.label || "No Label",
    color: node.data.color || def.NODE_COLOR,
    hcolor: node.data.hcolor || def.NODE_HIGHLIGHT,
    shape: node.data.shape || def.NODE_SHAPE,
    linecolor: new THREE.Color(0.5, 0.5, 0.5),
    numYeast: Math.ceil(Math.random() * 8),
    size: node.data.size,
    tsize: node.data.tsize || def.TEXT_SIZE,
    x: 0,
    y: 0,
    vx: 0,
    vy: 0
  };
  return nodeToAdd;
}

/**
 * Creates a generic rectangle shape to use for selection and boundaries
 */
var make1x1Rect = function() {
  var rectShape = new THREE.Shape();
  rectShape.moveTo(0, 0);
  rectShape.lineTo(0, 1);
  rectShape.lineTo(1, 1);
  rectShape.lineTo(1, 0);
  rectShape.lineTo(0, 0);
  rectShape.lineTo(0, 1);
  return new THREE.ShapeGeometry(rectShape);
};


/**
 * Creates a centered 2x2 Rectangle
 */
var make2x2Rect = function() {
  var rectShape = new THREE.Shape();
  rectShape.moveTo(-1, -1);
  rectShape.lineTo(-1, 1);
  rectShape.lineTo(1, 1);
  rectShape.lineTo(1, -1);
  rectShape.lineTo(-1, -1);
  return new THREE.ShapeGeometry(rectShape);
};

/**
 *  find radius of circle given the volume
 * @param {*} volume
 */
var volToRadius = function (volume) {
  return Math.pow((volume / Math.PI) * (3.0 / 4.0), 1.0 / 3.0)
}
  

exports.relMouseCoords = relMouseCoords;
exports.prepNode = prepNode;
exports.make1x1Rect = make1x1Rect;
exports.make2x2Rect = make2x2Rect;
exports.volToRadius = volToRadius;
